module vga_driver(
					clk,
					rst_n,
					hys,
					vys,
				    lcd_rgb 
               );
parameter     PICTURE_W    =   16 ;
parameter     ROW_W        =   10;
parameter    RANGE  = 2500;
parameter    X_CENT = 323;
parameter    Y_CENT = 242;
parameter    X_PRE_CENT = X_CENT + 141;
parameter    Y_PRE_CENT = Y_CENT +  32;

input                  clk      ;
input                  rst_n    ;

output                 hys      ;
output                 vys      ;


output [PICTURE_W-1:0] lcd_rgb;
reg    [PICTURE_W-1:0] lcd_rgb;

reg    [ROW_W-1:0]     h_cnt;
reg    [ROW_W-1:0]     v_cnt;
reg                    hys;
reg                    vys;
reg         valid_area ;
reg[19:0]   distance   ;



always@(posedge clk or negedge rst_n)begin
	if(!rst_n)begin
      	h_cnt <= 10'd0;
	 end
    else if(h_cnt == 10'd799)begin
        h_cnt <= 10'd0;
     end
    else begin
	    h_cnt <= h_cnt+1'b1;
     end
 end

 always@(posedge clk or negedge rst_n)begin
	if(!rst_n) begin
       v_cnt <= 10'd0;
    end
    else if(h_cnt == 10'd799)begin
        if(v_cnt==524)
            v_cnt <= 0;
        else
            v_cnt <= v_cnt+1;
    end
 end
	

always@(posedge clk or negedge rst_n)begin
    if(!rst_n)begin
        hys <= 0;
    end
    else if(h_cnt==10'd95)begin
        hys <= 1'b1;
    end
    else if(h_cnt==10'd799)begin
        hys <= 1'b0;
    end
end
	


always@(posedge clk or negedge rst_n)begin
    if(!rst_n)begin
        vys <= 1'b0;
    end
    else if(v_cnt<10'd2)begin
        vys <= 1'b0;
    end
    else begin
        vys <= 1'b1;
    end
end    



always  @(*)begin
    distance   = ((h_cnt - X_PRE_CENT) * (h_cnt - X_PRE_CENT)) + ((v_cnt - Y_PRE_CENT) * (v_cnt - Y_PRE_CENT));
end

always  @(*)begin
    valid_area = h_cnt >=141 && h_cnt <=786 && v_cnt >=32 && v_cnt <=515;
end



always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        lcd_rgb <= 0;
    end
    else if(valid_area)begin
        if(distance < RANGE)begin
            lcd_rgb <= 16'b00000_000000_11111;
        end
        else begin
            lcd_rgb <= 16'b11111_111111_11111;
        end
    end
    else begin
        lcd_rgb <= 0;
    end
end



endmodule
